# [silent](https://pub.dev/packages/silent)

Silent SDK is a technical solution for collecting some end user and mobile device data in the host application with minimal influence on the user experience

A Flutter plugin for iOS and Android

|             | Android | iOS     |
|-------------|---------|---------|
| **Support** | SDK 24+ | iOS 13+ |


## Installation

```yaml
dependencies:
  silent: ^0.0.4
```


# Setup

Initialize the SilentSdk with your credentials provided by [**mintech**](https://mintechbrasil.com.br/)  

```dart
Future<void> main() async {
  WidgetsFlutterBinding.ensureInitialized();

  await Silent.initialize(
      packageName: 'package-name',
      appId: 'credentials',
      appSecret: 'credentials');

  runApp(const MyApp());
} 
``` 
**Note**: [**Mintech**](https://mintechbrasil.com.br/)  will provide credentials (app_id and app_secret) based on your package name in Google Play.


- Android

Changes the version of kotlin in build.gradle
```text
buildscript {
    ext.kotlin_version = '1.8.20'
   ...
}
```

and in app/build.gradle 

```text
android {
    compileSdkVersion 33
    

    defaultConfig {  
        ...
        minSdkVersion 24
        targetSdkVersion 33 
        ...
    }

}
```

add dependency
```text
dependencies {
    ...
    implementation 'com.android.support:multidex:2.0.1'
}
```

### Requesting permission

Some properties require apps to explicitly request for user permission at runtime in order to be collected. SilentSDK offers three methods to request permission:

```dart
await Silent.requestLocation()
```

```dart
await Silent.requestTelephony()
```

```dart
await Silent.requestContacts()
``` 

**Note**: These methods are only available for ```android```

### Capture data

This method will collect data and upload into Mintech Servers in AWS South America.

```dart
await Silent.capture(uid: 'UID', loadId: 'LOAN_ID');
```

- UID: Unique identifier of the client logged into the app. Through this field it is possible to relate to which customer the captured data belongs. This identifier is provided by Mintech client.

- LOAN_ID: Unique identifier of the operation performed by the client. For example, credit card application code, loan application code, or others. This identifier is provided by Mintech client.


**Note**: As the data capture trigger occurs at app login, usually [**Mintech**](https://mintechbrasil.com.br/) receives only the UID value in both fields.

