import 'package:silent/src/silent_plugin.dart';

abstract class Silent {
  /// Returns true if the Silent SDK is initialized
  static Future<dynamic> initialize(
      {required String appId,
      required String appSecret,
      required String packageName}) {
    assert(appId.isNotEmpty);
    assert(appSecret.isNotEmpty);
    assert(packageName.isNotEmpty);
    return SilentPlugin().initialize(
        appId: appId, appSecret: appSecret, packageName: packageName);
  }

  /// [capture] push data captured
  /// [uid] Unique identifier of the client logged into the app.
  /// Through this field it is possible to relate to which customer the captured data belongs.
  /// This identifier is provided by Mintech client.
  ///
  /// [loadId] Unique identifier of the operation performed by the client.
  /// For example, credit card application code, loan application code, or others.
  /// This identifier is provided by Mintech client.
  static Future<dynamic> capture(
      {required String uid, required String loadId}) {
    assert(uid.isNotEmpty);
    assert(loadId.isNotEmpty);
    return SilentPlugin().capture(loadId: loadId, uid: uid);
  }

  /// Is the API key provided to this state valid with the Silent SDK ?
  static Future<bool> isValidated() {
    return SilentPlugin().isValidated();
  }

  /// [requestLocation] Ask for permission to get location of user
  /// Returns true if permission is given
  static Future<dynamic> requestLocation() {
    return SilentPlugin().requestLocation();
  }

  /// [requestTelephony] Ask for permission to get information about your device
  /// Returns true if permission is given
  static Future<dynamic> requestTelephony() {
    return SilentPlugin().requestTelephony();
  }

  /// [requestContacts] Ask for permission to get contacts of user
  /// Returns true if permission is given
  static Future<dynamic> requestContacts() {
    return SilentPlugin().requestContacts();
  }
}
